@@ -12,6 +12,7 @@
 # serve to show the default value.
 
 import sys, os, re
+from datetime import date
 
 # If your extensions are in another directory, add it here.
 #sys.path.append(os.path.dirname(__file__))
@@ -23,7 +24,7 @@ sys.path.append(os.path.abspath('../sphinxext'))
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.addons.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.pngmath','sphinx.ext.doctest']
+extensions = ['sphinx.ext.autodoc', 'sphinx.ext.imgmath','sphinx.ext.doctest']
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['templates']
@@ -35,11 +36,12 @@ source_suffix = '.rst'
 source_encoding = 'utf-8'
 
 # The master toctree document.
-master_doc = 'contents'
+master_doc = 'index'
 
 # General substitutions.
 project = 'PyGraphviz'
-copyright = '2010, Aric Hagberg'
+copyright = '2004-{}, PyGraphviz Developers'.format(date.today().year)
+
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
@@ -70,7 +72,7 @@ add_module_names = False
 show_authors = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'friendly'
+pygments_style = 'sphinx'
 
 
 # Options for HTML output
@@ -79,12 +81,12 @@ pygments_style = 'friendly'
 # The style sheet to use for HTML and HTML Help pages. A file of that name
 # must exist either in Sphinx' static/ path, or in one of the custom paths
 # given in html_static_path.
-html_style = 'sphinxdoc.css'
+#html_style = 'sphinxdoc.css'
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['static']
+#html_static_path = ['static']
 
 # If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
 # using the given strftime format.
@@ -95,19 +97,19 @@ html_last_updated_fmt = '%b %d, %Y'
 #html_use_smartypants = True
 
 # Content template for the index page.
-html_index = 'index.html'
+html_index = 'contents.html'
 
 # Custom sidebar templates, maps page names to templates.
-html_sidebars = {'index': 'indexsidebar.html'}
+#html_sidebars = {'index': 'indexsidebar.html'}
 
 # Additional templates that should be rendered to pages, maps page names to
 # templates.
-html_additional_pages = {'index': 'index.html'}
+#html_additional_pages = {'index': 'index.html'}
 
 # If true, the reST sources are included in the HTML build as _sources/<name>.
 html_copy_source = False
 
-html_use_opensearch = 'http://networkx.lanl.gov'
+html_use_opensearch = 'http://pygraphviz.github.io'
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = 'PyGraphviz'
@@ -125,8 +127,8 @@ latex_paper_size = 'letter'
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, document class [howto/manual]).
-latex_documents = [('contents', 'pygraphviz.tex', 'PyGraphviz Documentation',
-                    'Aric Hagberg, Dan Schult', 'manual', 1)]
+latex_documents = [('index', 'pygraphviz.tex', 'PyGraphviz Documentation',
+                    'PyGraphviz Developers', 'manual', 1)]
 
 
 #latex_use_parts = True
