@@ -198,11 +198,6 @@ class TestGraph:
         assert_equal(A.degree(1), 1)
         assert_equal(A.degree(2), 2)
 
-    def test_size(self):
-        A = pgv.AGraph()
-        A.add_edges_from([(1,2),(2,3)])
-        assert_equal(A.number_of_edges(), 2)
-        assert_equal(A.size(), 2)
 
     def test_clear(self):
         A = pgv.AGraph()
@@ -296,9 +291,14 @@ class TestDiGraphOnly(TestGraph):
                     [('1', '2'), ('2', '3')])
         assert_equal(sorted([tuple(sorted(e)) for e in A.in_edges_iter()]),
                     [('1', '2'), ('2', '3')])
+        assert_equal(sorted(A.edges(1)), [('1', '2')])
+        assert_equal(sorted(A.edges([1, 2])), [('1', '2'), ('2', '3')])
+        assert_equal(sorted(A.edges_iter(1)), [('1', '2')])
         assert_equal(sorted(A.out_edges(1)), [('1', '2')])
+        assert_equal(sorted(A.out_edges([1, 2])), [('1', '2'), ('2', '3')])
         assert_equal(sorted(A.out_edges_iter(1)), [('1', '2')])
         assert_equal(sorted(A.in_edges(2)), [('1', '2')])
+        assert_equal(sorted(A.in_edges([1, 2])), [('1', '2')])
         assert_equal(sorted(A.in_edges_iter(2)), [('1', '2')])
         assert_equal(A.predecessors(1), [])
         assert_equal(list(A.predecessors_iter(1)),[])
@@ -314,6 +314,8 @@ class TestDiGraphOnly(TestGraph):
         assert_equal(sorted(A.out_degree_iter()),
                      [('1', 1), ('2', 1), ('3', 0)])
         assert_equal(sorted(A.in_degree()), [0, 1, 1])
+        assert_equal(sorted(A.in_degree(with_labels=True).values()),
+                     [0, 1, 1])
         assert_equal(sorted(A.in_degree_iter()),
                      [('1', 0), ('2', 1), ('3', 1)])
 
@@ -322,18 +324,20 @@ class TestDiGraphOnly(TestGraph):
         assert_equal(A.in_degree(2), 1)
         assert_equal(A.out_degree(2), 1)
 
-        assert_equal(A.string().expandtabs(0),
+        # Have to use expandtabs(1) not 0 because of PyPy bug
+        # https://bitbucket.org/pypy/pypy/issues/2113/calling-strexpandtabs-0-crashes-with-a
+        assert_equal(A.string().expandtabs(1),
 """strict digraph {
-1 -> 2;
-2 -> 3;
+ 1 -> 2;
+ 2 -> 3;
 }
 """.replace('\n', linesep)
 )
 
-        assert_equal(A.reverse().string().expandtabs(0),
+        assert_equal(A.reverse().string().expandtabs(1),
 """strict digraph {
-2 -> 1;
-3 -> 2;
+ 2 -> 1;
+ 3 -> 2;
 }
 """.replace('\n', linesep)
 )
