@@ -5,7 +5,7 @@ Do not add this file to the repository.
 
 """
 
-__version__ = '1.3.1'
+__version__ = '1.5'
 __revision__ = None
-__date__ = 'Sun Sep  6 07:49:58 2015'
+__date__ = 'Mon Sep 10 15:18:40 2018'
 
